import { Component, Input, OnInit } from '@angular/core';
import { FormBuilder, FormControl, FormGroup, Validators } from '@angular/forms';
import { ClientEmailData } from '../config/sendgrid-url.config';
import { NgxPssSendgridService } from './ngx-pss-sendgrid.service';

@Component({
  selector: 'lib-ngx-pss-sendgrid',
  templateUrl: './ngx-pss-sendgrid.component.html',
  styleUrls: ['./ngx-pss-sendgrid.component.css']
})
export class NgxPssSendgridComponent implements OnInit {

  @Input() formTitle: string = 'Generic Contact Form';

  formData!: FormGroup;
  showModal: boolean = false;

  constructor(private sendGridService: NgxPssSendgridService, private builder: FormBuilder) { }

  ngOnInit(): void {
    this.formData = this.builder.group({
      email: new FormControl('', Validators.compose([Validators.required, Validators.email])),
      message: new FormControl('', Validators.required)
    })
  }

  onSubmit(values: any) {
    
    let emailData: ClientEmailData = {
      
      userEmail: values.email,
      content: this.createHtmlEmail(values.message)
    }

     this.sendGridService.sendEmail(emailData).subscribe({
      next: res => {
        if(res == "Message Processed") {
          //create a toast of the success message
          this.showModal = true;
        }
      }
     })
    
  }

  //This is the method that is responsible for formatting the message to an HTML email
  createHtmlEmail(message: string) {
    return "<div><h3>The Message From the user</h3><p>" + message + "</p></div>";
  }

}
